@@ -22,13 +22,12 @@
 #ifndef _ALINCO_H
 #define _ALINCO_H 1
 
-#include <hamlib/rig.h>
-#include <tones.h>
+#include "hamlib/rig.h"
 
 #define BACKEND_VER "20200323"
 
-extern const struct rig_caps dx77_caps;
-extern const struct rig_caps dxsr8_caps;
+extern struct rig_caps dx77_caps;
+extern struct rig_caps dxsr8_caps;
 
 #define BUFSZ 32
 
