@@ -25,7 +25,7 @@
 
 #include "hamlib/rig.h"
 #include "bandplan.h"
-#include "serial.h"
+#include "iofunc.h"
 #include "tones.h"
 
 #include "dra818.h"
