@@ -20,18 +20,20 @@
 *
 */
 
+#include "hamlib/config.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>             /* String function definitions */
 #include <math.h>
 
-#include <hamlib/rig.h>
-#include <serial.h>
-#include <misc.h>
-#include <token.h>
+#include "hamlib/rig.h"
+#include "iofunc.h"
+#include "misc.h"
+#include "token.h"
 
 #include "dummy_common.h"
 #include "flrig.h"
+#include "cache.h"
 
 #define DEBUG 1
 #define DEBUG_TRACE DEBUG_VERBOSE
@@ -52,7 +54,7 @@
                     RIG_MODE_FM | RIG_MODE_WFM | RIG_MODE_FMN | RIG_MODE_PKTFM |\
                     RIG_MODE_C4FM | RIG_MODE_DSTAR)
 
-#define FLRIG_LEVELS (RIG_LEVEL_AF | RIG_LEVEL_RF | RIG_LEVEL_MICGAIN | RIG_LEVEL_STRENGTH | RIG_LEVEL_RFPOWER_METER | RIG_LEVEL_RFPOWER_METER_WATTS | RIG_LEVEL_RFPOWER | RIG_LEVEL_SWR)
+#define FLRIG_LEVELS (RIG_LEVEL_AF | RIG_LEVEL_AGC | RIG_LEVEL_RF | RIG_LEVEL_MICGAIN | RIG_LEVEL_STRENGTH | RIG_LEVEL_RFPOWER_METER | RIG_LEVEL_RFPOWER_METER_WATTS | RIG_LEVEL_RFPOWER | RIG_LEVEL_SWR)
 
 #define FLRIG_PARM (TOK_FLRIG_VERIFY_FREQ|TOK_FLRIG_VERIFY_PTT)
 
@@ -141,9 +143,9 @@ static const struct confparams flrig_ext_parms[] =
 struct rig_caps flrig_caps =
 {
     RIG_MODEL(RIG_MODEL_FLRIG),
-    .model_name = "",
+    .model_name = "FLRig",
     .mfg_name = "FLRig",
-    .version = "20250107.0",
+    .version = "20260130.0",
     .copyright = "LGPL",
     .status = RIG_STATUS_STABLE,
     .rig_type = RIG_TYPE_TRANSCEIVER,
@@ -867,10 +869,6 @@ static int flrig_open(RIG *rig)
 
     strncpy(priv->info, value, sizeof(priv->info));
     rig_debug(RIG_DEBUG_VERBOSE, "Transceiver=%s\n", value);
-    char model_name[256];
-    snprintf(model_name,sizeof(model_name), "%.248s(%s)", value, "FLRig");
-    rig->caps->model_name = strdup(model_name);
-    STATE(rig)->model_name = strdup(model_name);
 
     /* see if get_pwrmeter_scale is available */
     retval = flrig_transaction(rig, "rig.get_pwrmeter_scale", NULL, value,
@@ -886,7 +884,7 @@ static int flrig_open(RIG *rig)
     /* see if get_modeA is available */
     retval = flrig_transaction(rig, "rig.get_modeA", NULL, value, sizeof(value));
 
-    if (retval == RIG_ENAVAIL) // must not have it
+    if (retval == -RIG_ENAVAIL) // must not have it
     {
         priv->has_get_modeA = 0;
         rig_debug(RIG_DEBUG_VERBOSE, "%s: getmodeA is not available=%s\n", __func__,
@@ -901,7 +899,7 @@ static int flrig_open(RIG *rig)
     /* see if get_modeB is available */
     retval = flrig_transaction(rig, "rig.get_modeB", NULL, value, sizeof(value));
 
-    if (retval == RIG_ENAVAIL) // must not have it
+    if (retval == -RIG_ENAVAIL) // must not have it
     {
         priv->has_get_modeB = 0;
         rig_debug(RIG_DEBUG_VERBOSE, "%s: getmodeB is not available=%s\n", __func__,
@@ -926,7 +924,7 @@ static int flrig_open(RIG *rig)
     retval = flrig_transaction(rig, "rig.get_bwA", NULL, value, sizeof(value));
     int dummy;
 
-    if (retval == RIG_ENAVAIL || value[0] == 0
+    if (retval == -RIG_ENAVAIL || value[0] == 0
             || sscanf(value, "%d", &dummy) <= 0) // must not have it
     {
         priv->has_get_bwA = 0;
@@ -945,7 +943,7 @@ static int flrig_open(RIG *rig)
     /* see if set_bwA is available */
     retval = flrig_transaction(rig, "rig.set_bwA", NULL, value, sizeof(value));
 
-    if (retval == RIG_ENAVAIL) // must not have it
+    if (retval == -RIG_ENAVAIL) // must not have it
     {
         priv->has_set_bwA = 0;
         priv->has_set_bwB = 0;
@@ -963,7 +961,7 @@ static int flrig_open(RIG *rig)
         // see if get_bwB is available FLRig can return empty value too
         retval = flrig_transaction(rig, "rig.get_bwB", NULL, value, sizeof(value));
 
-        if (retval == RIG_ENAVAIL || strlen(value) == 0) // must not have it
+        if (retval == -RIG_ENAVAIL || strlen(value) == 0) // must not have it
         {
             priv->has_get_bwB = 0;
             rig_debug(RIG_DEBUG_VERBOSE, "%s: get_bwB is not available=%s\n", __func__,
@@ -978,7 +976,7 @@ static int flrig_open(RIG *rig)
         /* see if set_bwB is available */
         retval = flrig_transaction(rig, "rig.set_bwB", NULL, value, sizeof(value));
 
-        if (retval == RIG_ENAVAIL) // must not have it
+        if (retval == -RIG_ENAVAIL) // must not have it
         {
             priv->has_set_bwB = 0;
             rig_debug(RIG_DEBUG_VERBOSE, "%s: set_bwB is not available=%s\n", __func__,
@@ -2375,6 +2373,8 @@ static int flrig_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
     case RIG_LEVEL_RFPOWER_METER_WATTS:
     case RIG_LEVEL_RFPOWER_METER: cmd = "rig.get_pwrmeter"; break;
 
+    case RIG_LEVEL_AGC: cmd = "rig.get_agc"; break; // flrig 2.0.6+
+
     default:
         rig_debug(RIG_DEBUG_ERR, "%s: unknown level=%d\n", __func__, (int)level);
         RETURNFUNC(-RIG_EINVAL);
@@ -2382,7 +2382,7 @@ static int flrig_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 
     retval = flrig_transaction(rig, cmd, NULL, value, sizeof(value));
 
-    if (retval == RIG_ENAVAIL && strcmp(cmd, "rig.get_SWR") == 0)
+    if (retval == -RIG_ENAVAIL && strcmp(cmd, "rig.get_SWR") == 0)
     {
         priv->get_SWR = 0;
         cmd = "rig.get_swrmeter"; // revert to old flrig method
@@ -2433,6 +2433,11 @@ static int flrig_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         rig_debug(RIG_DEBUG_TRACE, "%s: val.f='%s'(%g)\n", __func__, value, val->f);
         break;
 
+    case RIG_LEVEL_AGC: // flrig 2.0.6+
+        val->i = atoi(value);
+        rig_debug(RIG_DEBUG_TRACE, "%s: val.i='%s'(%d)\n", __func__, value, val->i);
+        break;
+
     default:
         val->f = atof(value) / 100;
         rig_debug(RIG_DEBUG_TRACE, "%s: val.f='%s'(%f)\n", __func__, value, val->f);
