@@ -24,10 +24,11 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include <hamlib/rig.h>
+#include "hamlib/rig.h"
 #include "kenwood.h"
 #include "token.h"
 #include "misc.h"
+#include "cache.h"
 #include "iofunc.h"
 #include "cal.h"
 
@@ -266,7 +267,7 @@ static struct kenwood_priv_caps  ts2000_priv_caps  =
  * Function definitions below
  */
 
-int ts2000_init(RIG *rig)
+static int ts2000_init(RIG *rig)
 {
     struct kenwood_priv_data *priv;
     int retval;
@@ -1752,6 +1753,7 @@ struct rig_caps ts2000_caps =
     .chan_list =  {
         { 0, 299, RIG_MTYPE_MEM, TS2000_MEM_CAP  },
         { 1,   3, RIG_MTYPE_MORSE },
+        { 1,   3, RIG_MTYPE_VOICE }, // Only if DRU-3A installed
         RIG_CHAN_END,
     },
 
@@ -2010,6 +2012,7 @@ struct rig_caps sdrconsole_caps =
     .chan_list =  {
         { 0, 299, RIG_MTYPE_MEM, TS2000_MEM_CAP  },
         { 1,   3, RIG_MTYPE_MORSE },
+        //{ 1,   3, RIG_MTYPE_VOICE }, // ??? Standard or optional ???
         RIG_CHAN_END,
     },
 
