@@ -27,6 +27,7 @@
 #include "hamlib/rig.h"
 #include "kenwood.h"
 #include "misc.h"
+#include "cache.h"
 #include "cal.h"
 #include "iofunc.h"
 
@@ -185,7 +186,7 @@ const struct confparams ts590_ext_levels[] =
  * This is not documented in the manual as of 3/11/15 but confirmed from Kenwood
  * "TY" produces "TYK 00" for example
  */
-const char *ts590_get_info(RIG *rig)
+static const char *ts590_get_info(RIG *rig)
 {
     char firmbuf[10];
     int retval;
@@ -1747,6 +1748,7 @@ struct rig_caps ts590_caps =
     .chan_list =  { /* TBC */
         {  0, 89, RIG_MTYPE_MEM,  TS590_CHANNEL_CAPS },
         { 90, 99, RIG_MTYPE_EDGE, TS590_CHANNEL_CAPS },
+        {  1,  4, RIG_MTYPE_VOICE },
         RIG_CHAN_END,
     },
 
@@ -1918,6 +1920,8 @@ struct rig_caps ts590_caps =
     .send_morse =  kenwood_send_morse,
     .stop_morse =  kenwood_stop_morse,
     .wait_morse =  rig_wait_morse,
+    .send_voice_mem = kenwood_send_voice_mem,
+    .stop_voice_mem = kenwood_stop_voice_mem,
     .set_mem =  kenwood_set_mem,
     .get_mem =  kenwood_get_mem,
     .vfo_ops = TS590_VFO_OPS,
@@ -1968,6 +1972,7 @@ struct rig_caps fx4_caps =
     .chan_list =  { /* TBC */
         {  0, 89, RIG_MTYPE_MEM,  TS590_CHANNEL_CAPS },
         { 90, 99, RIG_MTYPE_EDGE, TS590_CHANNEL_CAPS },
+        {  1,  4, RIG_MTYPE_VOICE }, //??? Standard ???
         RIG_CHAN_END,
     },
 
@@ -2179,6 +2184,7 @@ struct rig_caps ts590sg_caps =
         {  0, 89, RIG_MTYPE_MEM,  TS590_CHANNEL_CAPS },
         { 90, 99, RIG_MTYPE_EDGE, TS590_CHANNEL_CAPS },
         {  1,  3, RIG_MTYPE_MORSE },
+        {  1,  4, RIG_MTYPE_VOICE },
         RIG_CHAN_END,
     },
 
@@ -2349,6 +2355,8 @@ struct rig_caps ts590sg_caps =
     .send_morse =  kenwood_send_morse,
     .stop_morse =  kenwood_stop_morse,
     .wait_morse =  rig_wait_morse,
+    .send_voice_mem = kenwood_send_voice_mem,
+    .stop_voice_mem = kenwood_stop_voice_mem,
     .set_mem =  kenwood_set_mem,
     .get_mem =  kenwood_get_mem,
     .vfo_ops = TS590_VFO_OPS,
