@@ -22,7 +22,7 @@
 #ifndef _WJ_H
 #define _WJ_H 1
 
-#include <hamlib/rig.h>
+#include "hamlib/rig.h"
 #include "token.h"
 
 #define BACKEND_VER "20040912"
