@@ -33,8 +33,8 @@
 #ifndef _NEWCAT_H
 #define _NEWCAT_H 1
 
-#include <tones.h>
-#include <token.h>
+#include "tones.h"
+#include "token.h"
 
 /* Handy constants */
 
@@ -50,7 +50,7 @@
 typedef char ncboolean;
 
 /* shared function version */
-#define NEWCAT_VER "20230328"
+#define NEWCAT_VER "20241118"
 
 /* Hopefully large enough for future use, 128 chars plus '\0' */
 #define NEWCAT_DATA_LEN                 129
@@ -129,6 +129,16 @@ struct newcat_priv_data
     int poweron; /* to prevent powering on more than once */
     int question_mark_response_means_rejected; /* the question mark response has multiple meanings */
     char front_rear_status; /* e.g. FTDX5000 EX103 status */
+    int split_st_command_missing; /* is ST command gone?  assume not until proven otherwise */
+    int band_index;
+    /* FTX-1 specific fields - per-rig instance storage */
+    int ftx1_head_type;          /* FTX1_HEAD_FIELD_BATTERY/12V/SPA1/UNKNOWN */
+    int ftx1_spa1_detected;      /* 1 if SPA-1 confirmed via VE4 command */
+    int ftx1_detection_done;     /* 1 if auto-detection has been performed */
+    int ftx1_virtual_split;      /* Virtual split state (0=off, 1=on) */
+    vfo_t ftx1_tx_vfo;           /* TX VFO for virtual split */
+    int ftx1_cache_fix_needed;   /* 1 if Main cache needs restoration */
+    freq_t ftx1_cache_fix_freq;  /* Saved Main freq for cache restoration */
 };
 
 /*
@@ -171,9 +181,9 @@ int newcat_cleanup(RIG *rig);
 int newcat_open(RIG *rig);
 int newcat_close(RIG *rig);
 
-int newcat_set_conf(RIG *rig, token_t token, const char *val);
-int newcat_get_conf(RIG *rig, token_t token, char *val);
-int newcat_get_conf2(RIG *rig, token_t token, char *val, int val_len);
+int newcat_set_conf(RIG *rig, hamlib_token_t token, const char *val);
+int newcat_get_conf(RIG *rig, hamlib_token_t token, char *val);
+int newcat_get_conf2(RIG *rig, hamlib_token_t token, char *val, int val_len);
 
 int newcat_set_freq(RIG *rig, vfo_t vfo, freq_t freq);
 int newcat_get_freq(RIG *rig, vfo_t vfo, freq_t *freq);
@@ -195,6 +205,8 @@ int newcat_set_level(RIG * rig, vfo_t vfo, setting_t level, value_t val);
 int newcat_get_level(RIG * rig, vfo_t vfo, setting_t level, value_t * val);
 int newcat_set_func(RIG * rig, vfo_t vfo, setting_t func, int status);
 int newcat_get_func(RIG * rig, vfo_t vfo, setting_t func, int *status);
+int newcat_set_parm(RIG * rig, setting_t parm, value_t val);
+int newcat_get_parm(RIG * rig, setting_t parm, value_t *val);
 int newcat_set_mem(RIG * rig, vfo_t vfo, int ch);
 int newcat_get_mem(RIG * rig, vfo_t vfo, int *ch);
 int newcat_vfo_op(RIG * rig, vfo_t vfo, vfo_op_t op);
@@ -204,6 +216,8 @@ int newcat_get_rit(RIG * rig, vfo_t vfo, shortfreq_t * rit);
 int newcat_set_rit(RIG * rig, vfo_t vfo, shortfreq_t rit);
 int newcat_get_xit(RIG * rig, vfo_t vfo, shortfreq_t * xit);
 int newcat_set_xit(RIG * rig, vfo_t vfo, shortfreq_t xit);
+int newcat_get_clarifier_frequency(RIG *rig, vfo_t vfo, shortfreq_t *freq);
+int newcat_set_clarifier_frequency(RIG *rig, vfo_t vfo, shortfreq_t freq);
 int newcat_power2mW(RIG * rig, unsigned int *mwpower, float power, freq_t freq, rmode_t mode);
 int newcat_mW2power(RIG * rig, float *power, unsigned int mwpower, freq_t freq, rmode_t mode);
 int newcat_set_split_vfo(RIG * rig, vfo_t vfo, split_t split, vfo_t tx_vfo);
@@ -228,8 +242,8 @@ rmode_t newcat_rmode(char mode);
 char newcat_modechar(rmode_t rmode);
 rmode_t newcat_rmode_width(RIG *rig, vfo_t vfo, char mode, pbwidth_t *width);
 
-int newcat_set_ext_level(RIG *rig, vfo_t vfo, token_t token, value_t val);
-int newcat_get_ext_level(RIG *rig, vfo_t vfo, token_t token, value_t *val);
+int newcat_set_ext_level(RIG *rig, vfo_t vfo, hamlib_token_t token, value_t val);
+int newcat_get_ext_level(RIG *rig, vfo_t vfo, hamlib_token_t token, value_t *val);
 
 int newcat_send_morse(RIG *rig, vfo_t vfo, const char *msg);
 int newcat_send_voice_mem(RIG *rig, vfo_t vfo, int ch);
@@ -249,5 +263,11 @@ int newcat_scan(RIG *rig, vfo_t vfo, scan_t scan, int ch);
 #define TOK_CONTOUR_FREQ   TOKEN_BACKEND(105)
 #define TOK_CONTOUR_LEVEL  TOKEN_BACKEND(106)
 #define TOK_CONTOUR_WIDTH  TOKEN_BACKEND(107)
+#define TOK_MAXPOWER_HF    TOKEN_BACKEND(108)
+#define TOK_MAXPOWER_6M    TOKEN_BACKEND(109)
+#define TOK_MAXPOWER_4M    TOKEN_BACKEND(110)
+#define TOK_MAXPOWER_AM    TOKEN_BACKEND(111)
+#define TOK_MAXPOWER_VHF   TOKEN_BACKEND(112)
+#define TOK_MAXPOWER_UHF   TOKEN_BACKEND(113)
 
 #endif /* _NEWCAT_H */
