@@ -37,7 +37,8 @@
 #include <ctype.h>            /* for isdigit function */
 
 #include "hamlib/rotator.h"
-#include "serial.h"
+#include "hamlib/port.h"
+#include "hamlib/rot_state.h"
 #include "register.h"
 #include "iofunc.h"
 #include "misc.h"
