@@ -1,2 +1,2 @@
 /* This date time is from the last non-merge commit to Hamlib. */
-#define HAMLIBDATETIME "2025-09-05T19:49:48Z SHA=8a6bd5"
+#define HAMLIBDATETIME "2026-02-15T21:14:25Z SHA=554e02b39"
