@@ -24,7 +24,7 @@
  */
 /* SPDX-License-Identifier: GPL-2.0-or-later */
 
-#include <hamlib/config.h>
+#include "hamlib/config.h"
 
 #ifdef WIN32
 #define WIN32_LEAN_AND_MEAN
@@ -64,11 +64,9 @@
 #  include <netdb.h>
 #endif
 
-#ifdef HAVE_PTHREAD
-#  include <pthread.h>
-#endif
+#include <pthread.h>
 
-#include <hamlib/rig.h>
+#include "hamlib/rig.h"
 #include "misc.h"
 #include "network.h"
 
@@ -125,17 +123,18 @@ struct handle_data
 };
 
 
+/*
+ * Prototypes
+ */
 void *handle_socket(void *arg);
-void usage(void);
+static void usage(FILE *fout);
+static void short_usage(FILE *fout);
 
-
-#ifdef HAVE_PTHREAD
 static unsigned client_count;
-#endif
 
 static RIG *my_rig;             /* handle to rig (instance) */
 static volatile int rig_opened = 0;
-static int verbose;
+static int verbose = RIG_DEBUG_NONE;
 
 #ifdef HAVE_SIG_ATOMIC_T
 static sig_atomic_t volatile ctrl_c = 0;
@@ -159,7 +158,6 @@ static int bind_all = 0;
 
 void mutex_rigctld(int lock)
 {
-#ifdef HAVE_PTHREAD
     static pthread_mutex_t client_lock = PTHREAD_MUTEX_INITIALIZER;
 
     if (lock)
@@ -173,7 +171,6 @@ void mutex_rigctld(int lock)
         pthread_mutex_unlock(&client_lock);
     }
 
-#endif
 }
 
 #ifdef WIN32
@@ -256,7 +253,7 @@ int main(int argc, char *argv[])
     ptt_type_t ptt_type = RIG_PTT_NONE;
     dcd_type_t dcd_type = RIG_DCD_NONE;
     int serial_rate = 0;
-    char *civaddr = NULL;   /* NULL means no need to set conf */
+    const char *civaddr = NULL;   /* NULL means no need to set conf */
     char conf_parms[MAXCONFLEN] = "";
 
     struct addrinfo hints, *result, *saved_result;
@@ -273,11 +270,8 @@ int main(int argc, char *argv[])
     struct sigaction act;
 #endif
 
-#ifdef HAVE_PTHREAD
     pthread_t thread;
     pthread_attr_t attr;
-#endif
-    struct handle_data *arg;
     int vfo_mode = 0; /* vfo_mode=0 means target VFO is current VFO */
     int i;
     extern int is_rigctld;
@@ -288,7 +282,7 @@ int main(int argc, char *argv[])
 
     if (err) { rig_debug(RIG_DEBUG_ERR, "%s: setvbuf err=%s\n", __func__, strerror(err)); }
 
-
+    rig_set_debug(verbose);
     while (1)
     {
         int c;
@@ -309,7 +303,7 @@ int main(int argc, char *argv[])
         switch (c)
         {
         case 'h':
-            usage();
+            usage(stdout);
             exit(0);
 
         case 'V':
@@ -334,52 +328,22 @@ int main(int argc, char *argv[])
             break;
 
         case 'm':
-            if (!optarg)
-            {
-                usage();    /* wrong arg count */
-                exit(1);
-            }
-
             my_model = atoi(optarg);
             break;
 
         case 'r':
-            if (!optarg)
-            {
-                usage();    /* wrong arg count */
-                exit(1);
-            }
-
             rig_file = optarg;
             break;
 
         case 'p':
-            if (!optarg)
-            {
-                usage();    /* wrong arg count */
-                exit(1);
-            }
-
             ptt_file = optarg;
             break;
 
         case 'd':
-            if (!optarg)
-            {
-                usage();    /* wrong arg count */
-                exit(1);
-            }
-
             dcd_file = optarg;
             break;
 
         case 'P':
-            if (!optarg)
-            {
-                usage();    /* wrong arg count */
-                exit(1);
-            }
-
             if (!strcmp(optarg, "RIG"))
             {
                 ptt_type = RIG_PTT_RIG;
@@ -421,12 +385,6 @@ int main(int argc, char *argv[])
             break;
 
         case 'D':
-            if (!optarg)
-            {
-                usage();    /* wrong arg count */
-                exit(1);
-            }
-
             if (!strcmp(optarg, "RIG"))
             {
                 dcd_type = RIG_DCD_RIG;
@@ -472,33 +430,15 @@ int main(int argc, char *argv[])
             break;
 
         case 'c':
-            if (!optarg)
-            {
-                usage();    /* wrong arg count */
-                exit(1);
-            }
-
             civaddr = optarg;
             break;
 
         case 'S':
-            if (!optarg)
-            {
-                usage();    /* wrong arg count */
-                exit(1);
-            }
-
             resp_sep = *optarg;
             rig_debug(RIG_DEBUG_VERBOSE, "%s: resp_sep=%c\n", __func__, resp_sep);
             break;
 
         case 's':
-            if (!optarg)
-            {
-                usage();    /* wrong arg count */
-                exit(1);
-            }
-
             if (sscanf(optarg, "%d%1s", &serial_rate, dummy) != 1)
             {
                 fprintf(stderr, "Invalid baud rate of %s\n", optarg);
@@ -508,12 +448,6 @@ int main(int argc, char *argv[])
             break;
 
         case 'C':
-            if (!optarg)
-            {
-                usage();    /* wrong arg count */
-                exit(1);
-            }
-
             if (strcmp(optarg, "auto_power_on=0") == 0)
             {
                 rig_debug(RIG_DEBUG_ERR, "%s: skipping rig_open\n", __func__);
@@ -540,22 +474,10 @@ int main(int argc, char *argv[])
             break;
 
         case 't':
-            if (!optarg)
-            {
-                usage();    /* wrong arg count */
-                exit(1);
-            }
-
             portno = optarg;
             break;
 
         case 'T':
-            if (!optarg)
-            {
-                usage();    /* wrong arg count */
-                exit(1);
-            }
-
             src_addr = optarg;
             break;
 
@@ -566,6 +488,7 @@ int main(int argc, char *argv[])
 
         case 'v':
             verbose++;
+            rig_set_debug(verbose);
             break;
 
         case 'L':
@@ -581,24 +504,12 @@ int main(int argc, char *argv[])
             break;
 
         case 'W':
-            if (!optarg)
-            {
-                usage();    /* wrong arg count */
-                exit(1);
-            }
-
             twiddle_timeout = atoi(optarg);
             fprintf(stderr,
                     "twiddle_timeout is deprecated...use e.g. --set-conf=twiddle_timeout=5\n");
             break;
 
         case 'w':
-            if (!optarg)
-            {
-                usage();    /* wrong arg count */
-                exit(1);
-            }
-
             twiddle_rit = atoi(optarg);
             fprintf(stderr,
                     "twiddle_rit is deprecated...use e.g. --set-conf=twiddle_rit=1\n");
@@ -606,12 +517,6 @@ int main(int argc, char *argv[])
 
 
         case 'x':
-            if (!optarg)
-            {
-                usage();    /* wrong arg count */
-                exit(1);
-            }
-
             uplink = atoi(optarg);
             break;
 
@@ -621,7 +526,8 @@ int main(int argc, char *argv[])
             break;
 
         default:
-            usage();    /* unknown option? */
+            /* unknown getopt option */
+            short_usage(stderr);
             exit(1);
         }
     }
@@ -636,8 +542,6 @@ int main(int argc, char *argv[])
 
 #endif
 
-    rig_set_debug(verbose);
-
     SNPRINTF(rigstartup, sizeof(rigstartup), "%s(%d) Startup:", __FILE__, __LINE__);
 
     for (i = 0; i < argc; ++i) { strcat(rigstartup, " "); strcat(rigstartup, argv[i]); }
@@ -663,7 +567,7 @@ int main(int argc, char *argv[])
     }
 
     my_rig->caps->ptt_type = ptt_type;
-    char *token = strtok(conf_parms, ",");
+    const char *token = strtok(conf_parms, ",");
     struct rig_state *rs = STATE(my_rig);
 
     while (token)
@@ -733,7 +637,7 @@ int main(int argc, char *argv[])
         if (ptt_type == RIG_PTT_NONE)
         {
             rig_debug(RIG_DEBUG_VERBOSE, "%s: defaulting to RTS PTT\n", __func__);
-            my_rig->caps->ptt_type = ptt_type = RIG_PTT_SERIAL_RTS;
+            my_rig->caps->ptt_type = RIG_PTT_SERIAL_RTS;
         }
     }
 
@@ -873,7 +777,7 @@ int main(int argc, char *argv[])
     else
     {
         fprintf(stderr, "getaddrinfo: %s\n", gai_strerror(retcode));
-        exit(2);
+        exit(1);
     }
 
     saved_result = result;
@@ -888,7 +792,7 @@ int main(int argc, char *argv[])
         {
             handle_error(RIG_DEBUG_ERR, "socket");
             freeaddrinfo(saved_result);     /* No longer needed */
-            exit(2);
+            exit(1);
         }
 
         const int optval = 1;
@@ -1083,16 +987,6 @@ int main(int argc, char *argv[])
         fd_set set;
         struct timeval timeout;
 
-        arg = calloc(1, sizeof(struct handle_data));
-
-        if (!arg)
-        {
-            rig_debug(RIG_DEBUG_ERR, "calloc: %s\n", strerror(errno));
-            exit(1);
-        }
-
-        if (rigctld_password[0] != 0) { arg->use_password = 1; }
-
         /* use select to allow for periodic checks for CTRL+C */
         FD_ZERO(&set);
         FD_SET(sock_listen, &set);
@@ -1129,6 +1023,18 @@ int main(int argc, char *argv[])
         }
         else
         {
+            struct handle_data *arg;
+
+            arg = calloc(1, sizeof(struct handle_data));
+
+            if (!arg)
+            {
+                rig_debug(RIG_DEBUG_ERR, "calloc: %s\n", strerror(errno));
+                exit(1);
+            }
+
+            if (rigctld_password[0] != 0) { arg->use_password = 1; }
+
             arg->rig = my_rig;
             arg->clilen = sizeof(arg->cli_addr);
             arg->vfo_mode = vfo_mode;
@@ -1139,6 +1045,7 @@ int main(int argc, char *argv[])
             if (arg->sock < 0)
             {
                 handle_error(RIG_DEBUG_ERR, "accept");
+                free(arg);
                 break;
             }
 
@@ -1161,7 +1068,6 @@ int main(int argc, char *argv[])
                       host,
                       serv);
 
-#ifdef HAVE_PTHREAD
             pthread_attr_init(&attr);
             pthread_attr_setdetachstate(&attr, PTHREAD_CREATE_DETACHED);
 
@@ -1173,16 +1079,12 @@ int main(int argc, char *argv[])
                 break;
             }
 
-#else
-            handle_socket(arg);
-#endif
         }
     }
     while (!ctrl_c);
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: while loop done\n", __func__);
 
-#ifdef HAVE_PTHREAD
     /* allow threads to finish current action */
     mutex_rigctld(1);
 
@@ -1198,9 +1100,6 @@ int main(int argc, char *argv[])
 #endif
     rig_close(my_rig);
     mutex_rigctld(0);
-#else
-    rig_close(my_rig); /* close port */
-#endif
 
     rig_cleanup(my_rig); /* if you care about memory */
 
@@ -1276,7 +1175,6 @@ void *handle_socket(void *arg)
         goto handle_exit;
     }
 
-#ifdef HAVE_PTHREAD
     mutex_rigctld(1);
 
     ++client_count;
@@ -1297,19 +1195,6 @@ void *handle_socket(void *arg)
 #endif
 
     mutex_rigctld(0);
-#else
-    mutex_rigctld(1);
-    retcode = rig_open(my_rig);
-    mutex_rigctld(0);
-
-    if (RIG_OK == retcode && verbose > RIG_DEBUG_ERR)
-    {
-        printf("Opened rig model %d, '%s'\n",
-               my_rig->caps->rig_model,
-               my_rig->caps->model_name);
-    }
-
-#endif
 
     if (my_rig->caps->get_powerstat)
     {
@@ -1373,7 +1258,7 @@ void *handle_socket(void *arg)
 
         // if we get a hard error we try to reopen the rig again
         // this should cover short dropouts that can occur
-        if (retcode < 0 && !RIG_IS_SOFT_ERRCODE(-retcode))
+        if (retcode < 0 && !RIG_IS_SOFT_ERRCODE(retcode))
         {
             int retry = 3;
             rig_debug(RIG_DEBUG_ERR, "%s: i/o error\n", __func__);
@@ -1403,23 +1288,18 @@ void *handle_socket(void *arg)
             while (!ctrl_c && !rig_opened && retry-- > 0 && retcode != RIG_OK);
         }
     }
-    while (!ctrl_c && (retcode == RIG_OK || RIG_IS_SOFT_ERRCODE(-retcode)));
-
-#if defined(HAVE_PTHREAD)
+    while (!ctrl_c && (retcode == RIG_OK || RIG_IS_SOFT_ERRCODE(retcode)));
 
+    mutex_rigctld(1);
     if (rigctld_idle && client_count == 1)
-#else
-    if (rigctld_idle)
-#endif
     {
         rig_close(my_rig);
 
         if (verbose > RIG_DEBUG_ERR) { printf("Closed rig model %s.  Will reopen for new clients\n", my_rig->caps->model_name); }
     }
 
-
-#ifdef HAVE_PTHREAD
     --client_count;
+    mutex_rigctld(0);
 
     if (rigctld_idle && client_count > 0) { printf("%u client%s still connected so rig remains open\n", client_count, client_count > 1 ? "s" : ""); }
 
@@ -1440,17 +1320,6 @@ void *handle_socket(void *arg)
     }
 
     mutex_rigctld(0);
-#endif
-#else
-    rig_close(my_rig);
-
-    if (verbose > RIG_DEBUG_ERR)
-    {
-        printf("Closed rig model %d, '%s - will reopen for new clients'\n",
-               my_rig->caps->rig_model,
-               my_rig->caps->model_name);
-    }
-
 #endif
 
     if ((retcode = getnameinfo((struct sockaddr const *)&handle_data_arg->cli_addr,
@@ -1495,20 +1364,18 @@ handle_exit:
 
     free(arg);
 
-#ifdef HAVE_PTHREAD
     pthread_exit(NULL);
-#endif
     return NULL;
 }
 
 
-void usage(void)
+static void usage(FILE *fout)
 {
-    printf("Usage: rigctld [OPTION]...\n"
+    fprintf(fout, "Usage: rigctld [OPTION]...\n"
            "Daemon serving COMMANDs to a connected radio transceiver or receiver.\n\n");
 
 
-    printf(
+    fprintf(fout,
         "  -m, --model=ID                select radio model number. See model list (-l)\n"
         "  -r, --rig-file=DEVICE         set device of the radio to operate on\n"
         "  -p, --ptt-file=DEVICE         set device of the PTT device to operate on\n"
@@ -1528,7 +1395,7 @@ void usage(void)
         "  -v, --verbose                 set verbose mode, cumulative (-v to -vvvvv)\n"
         "  -W, --twiddle_timeout=SECONDS timeout after detecting vfo manual change\n"
         "  -w, --twiddle_rit=SECONDS     suppress VFOB getfreq so RIT can be twiddled\n"
-        "  -x, --uplink=OPTION           set uplink get_freq ignore: option 1=Sub, 2=Main\n"
+        "  -x, --uplink=OPTION           set uplink get_freq ignore, option 1=Sub, 2=Main\n"
         "  -Z, --debug-time-stamps       enable time stamps for debug messages\n"
         "  -A, --password=PASSWORD       set password for rigctld access (NOT IMPLEMENTED)\n"
         "  -R, --rigctld-idle            make rigctld close the rig when no clients are connected\n"
@@ -1537,16 +1404,13 @@ void usage(void)
         "  -V, --version                 output version information and exit\n\n",
         portno);
 
-    usage_rig(stdout);
+    usage_rig(fout);
+}
 
-    printf("\nError codes and messages\n");
 
-    for (enum rig_errcode_e e = 0; e < RIG_EEND; ++e)
-    {
-        printf("-%d - %s", e, rigerror2(e));
-    }
-
-
-    printf("\nReport bugs to <hamlib-developer@lists.sourceforge.net>.\n");
-
+static void short_usage(FILE *fout)
+{
+    fprintf(fout, "Usage: rigctld [OPTION]... [-m ID] [-r DEVICE] [-s BAUD]\n");
+    fprintf(fout, "Daemon serving COMMANDs to a connected radio transceiver or receiver.\n\n");
+    fprintf(fout, "Type: rigctld --help for extended usage.\n");
 }
